<?php
/** @file Archport utility functions. */

/**
 * Prepare the export directory for a node based on its type and id.
 *
 * @param string $archport_directory A file uri to the archport directory. Like
 *                                   private://archport.
 * @param string $type               The content type of the node the directory
 *                                   is being prepared for.
 * @param int    $id                 The id of the node the directory is being
 *                                   prepared for.
 *
 * @return false|string
 */
function _archport_prepare_node_dir(
  string $archport_directory,
  string $type,
  int $id
) {
  $directory = $archport_directory . '/' . $type . '/' . $id;
  $prepare_directory = _archport_prepare_directory($directory);
  if (!$prepare_directory) {
    echo t(
        "Archport - prepare_node_dir - Failed to prepare destination directory for node exports."
      ) . $directory . "\n";
    return FALSE;
  }
  else {
    return $directory;
  }
}

/**
 * Create the directory if it does not exist. Uses mode 0770, and is recursive.
 *
 * @param string $directory A directory path or uri.
 *
 * @return bool|string
 */
function _archport_prepare_directory(string $directory) {
  if (!file_exists($directory)) {
    $prepare_directory = drupal_mkdir($directory, 0770, TRUE);
    if (!$prepare_directory) {
      echo t(
          "Archport - prepare_directory - Failed to prepare directory."
        ) . $directory . "\n";
      return FALSE;
    }
  }
  return $directory;
}

/**
 * Get all the field names.
 *
 * @return array
 */
function _archport_get_all_node_field_names(): array {
  return array_keys(field_info_field_map());
}

/**
 * Get all the node entity types.
 *
 * @return array
 */
function _archport_get_all_node_entity_types(): array {
  return array_keys(node_type_get_names());
}

/**
 * Returns the first section of a given uri. "public://test/foo/bar" will
 * return "public://test".
 *
 * @param $uri
 *
 * @return string
 */
function _archport_get_archport_directory_from_uri($uri) {
  $target = file_uri_target($uri);
  $scheme = file_uri_scheme($uri);
  $explode = explode('/', $target);
  return $scheme . '://' . $explode[0];
}
